Documentation
¶
Index ¶
Constants ¶
const ( EMPTY = iota USERSTORAGE = iota USERSTREAM = iota LOCKBYTES = iota PROPERTY = iota ROOT = iota )
File types in OLE2 directory
const ENDOFCHAIN = uint32(0xFFFFFFFE) //-2
const FREESECT = uint32(0xFFFFFFFF) // -1
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type File ¶
type File struct {
NameBts [32]uint16
Bsize uint16
Type byte
Flag byte
Left uint32
Right uint32
Child uint32
Guid [8]uint16
Userflags uint32
Time [2]uint64
Sstart uint32
Size uint32
Proptype uint32
}
File represents an entry in the OLE2 directory
type Header ¶
type Header struct {
Id [2]uint32
Clid [4]uint32
Verminor uint16
Verdll uint16
Byteorder uint16
Lsectorb uint16
Lssectorb uint16
Cfat uint32 //Total number of sectors used for the sector allocation table
Dirstart uint32 //SecID of first sector of the directory stream
Sectorcutoff uint32 //Minimum size of a standard stream
Sfatstart uint32 //SecID of first sector of the short-sector allocation table
Csfat uint32 //Total number of sectors used for the short-sector allocation table
Difstart uint32 //SecID of first sector of the master sector allocation table
Cdif uint32 //Total number of sectors used for the master sector allocation table
Msat [109]uint32
// contains filtered or unexported fields
}
Header represents the OLE2 compound file header
type Ole ¶
type Ole struct {
Lsector uint32
Lssector uint32
SecID []uint32
SSecID []uint32
Files []File
// contains filtered or unexported fields
}
Ole represents an OLE2 compound file
type Sector ¶
type Sector []byte
Sector represents a sector in OLE2 file
func (*Sector) MsatValues ¶
type StreamReader ¶
type StreamReader struct {
// contains filtered or unexported fields
}
StreamReader reads streams from OLE2 file
Click to show internal directories.
Click to hide internal directories.